==> mx-boot-options_19.5.1.tar.xz: mx-boot-options-19.5.1/translations/mx-boot-options_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>CustomDialog</name>
    <message>
        <location filename="../dialog.cpp" line="15"/>
        <source>Live environment detected. Please select the root partition of the
 system you want to modify (only Linux partitions are displayed)</source>
        <translation>Ambiente USB-Executável detectado. Por favor selecione a partição root do
sistema que você quer modificar (apenas partições Linux serão mostradas)</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="22"/>
        <source>OK</source>
        <translation>Aceitar</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="23"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="29"/>
        <source>Options</source>
        <translation>Opções</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="35"/>
        <source>Kernel parameters</source>
        <translation>Parâmetros do Núcleo (Kernel)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>Set to &apos;0&apos; to boot immediately without displaying the menu, or to &apos;-1&apos; to wait indefinitely</source>
        <translation>Ajuste para &quot;0&quot; para iniciar imediatamente sem mostrar o menu, ou, para &quot;-1&quot; para aguardar indefinidamente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="58"/>
        <source>Menu timeout</source>
        <translation>Tempo de espera do menu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="71"/>
        <source>Boot to</source>
        <translation>Iniciar para</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="78"/>
        <source>Use simplified menu structure without submenus</source>
        <translation>Usar menu de estrutura simplificada sem submenus</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="81"/>
        <source>Use flat menus (no submenus)</source>
        <translation>Usar menus condensados (sem submenus)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="110"/>
        <source>seconds</source>
        <translation>segundos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>With this option enabled whatever entry you select from the grub boot menu will be saved as the new default for future boots</source>
        <translation>Com essa opção habilitada qualquer entrada que você selecionar do menu de inicialização do grub será o novo padrão para inicializações futuras</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="120"/>
        <source>Enable saving last boot choice</source>
        <translation>Habilita salvamento da última escolha de inicialização</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="133"/>
        <source>Background</source>
        <translation>Tela de fundo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="151"/>
        <source>Image</source>
        <translation>Imagem</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="164"/>
        <location filename="../mainwindow.ui" line="266"/>
        <source>Enable theme</source>
        <translation>Habilitar tema</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="244"/>
        <source>Splash</source>
        <translation>Tela de início</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="279"/>
        <source>Preview</source>
        <translation>Pré-visualização</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="302"/>
        <source>Messages</source>
        <translation>Mensagens</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="308"/>
        <source>Very detailed</source>
        <translation>Bem detalhado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="315"/>
        <source>Detailed (default setting)</source>
        <translation>Detalhado (ajuste padrão)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="325"/>
        <source>Limited</source>
        <translation>Limitado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <source>Display log</source>
        <translation>Exibir o relatório</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="394"/>
        <source>Display help </source>
        <translation>Exibir a ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="397"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="404"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="436"/>
        <source>About this application</source>
        <translation>Sobre esta aplicação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="439"/>
        <source>About...</source>
        <translation>Sobre...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="446"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="481"/>
        <source>Quit application</source>
        <translation>Sair da aplicação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="484"/>
        <location filename="../mainwindow.cpp" line="680"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="491"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="532"/>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="71"/>
        <source>Still running</source>
        <translation>Ainda rodando</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="164"/>
        <source>Installing bootsplash, please wait</source>
        <translation>Instalando tela de inicialização, favor aguardar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="171"/>
        <source>Updating sources</source>
        <translation>Atualizando fontes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="173"/>
        <source>Installing</source>
        <translation>Instalando</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="178"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="178"/>
        <source>Could not install the bootsplash.</source>
        <translation>Não pôde instalar a tela de inicialização</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="280"/>
        <location filename="../mainwindow.cpp" line="326"/>
        <source>Cannot continue</source>
        <translation>Não pode continuar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="280"/>
        <source>Nothing was selected, cannot change boot options. Exiting...</source>
        <translation>Nada foi selecionado, não pode mudar opções de inicialização. Saindo...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="326"/>
        <source>Cannot create chroot environment, cannot change boot options. Exiting...</source>
        <translation>Não pode criar ambiente chroot, não pode mudar opções de inicialização. Saindo...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="574"/>
        <location filename="../mainwindow.cpp" line="885"/>
        <source>Updating configuration, please wait</source>
        <translation>Atualizando configuração, favor aguardar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="625"/>
        <source>Updating initramfs...</source>
        <translation>Atualizando initramfs...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="634"/>
        <location filename="../mainwindow.cpp" line="898"/>
        <source>Updating grub...</source>
        <translation>Atualizando grub...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="637"/>
        <source>Done</source>
        <translation>Feito</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="637"/>
        <source>Changes have been successfully applied.</source>
        <translation>Mudanças têm sido aplicadas com sucesso</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="650"/>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="651"/>
        <source>Version: </source>
        <translation>Versão: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="652"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Programa para selecionar escolhas comuns de inicialização</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="654"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Direitos de Autor (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="655"/>
        <location filename="../mainwindow.cpp" line="667"/>
        <source>License</source>
        <translation>Licença</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="656"/>
        <source>Changelog</source>
        <translation>Relatório de alterações</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="657"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="699"/>
        <source>MX Boot Options</source>
        <translation>MX Opções de Inicialização</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="713"/>
        <source>Running in a Virtual Machine</source>
        <translation>Rodando em uma Máquina Virtual</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="714"/>
        <source>You current system is running in a Virtual Machine,
Plymouth bootsplash will work in a limited way, you also won&apos;t be able to preview the theme</source>
        <translation>Seu sistema atual está rodando numa Máquina Virtual,
a tela do Plymouth irá trabalhar numa maneira limitada, você também não poderá pré-visualizar o tema.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="719"/>
        <source>Plymouth packages not installed</source>
        <translation>Pacotes do Plymouth não instalados</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="719"/>
        <source>Plymouth packages are not currently installed.
OK to go ahead and install them?</source>
        <translation>Pacotes do Plymouth atualmente não instalados.
Quer prosseguir e instalá-los?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="740"/>
        <source>Images (*.png *.jpg *.jpeg *.tga)</source>
        <translation>Imagens (*.png *.jpg *.jpeg *.tga)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="848"/>
        <source>Press any key to close</source>
        <translation>Pressione qualquer tecla para fechar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="850"/>
        <source>Log not found</source>
        <translation>Relatório não encontrado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="850"/>
        <source>Could not find log at </source>
        <translation>Não pude encontrar relatório em</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="864"/>
        <source>Needs reboot</source>
        <translation>Precisa reiniciar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="864"/>
        <source>Plymouth was just installed, you might need to reboot before being able to display previews</source>
        <translation>Plymouth acabou de ser instalado, você deveria reiniciar antes para poder exibir as pré-visualizações </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="920"/>
        <source>Click to select theme</source>
        <translation>Clique para selecionar o tema</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>You must run this program as root.</source>
        <translation>Você deve executar este programa como root.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../mainwindow.cpp" line="739"/>
        <source>Select image to display in bootloader</source>
        <translation>Selecione imagem para exibir no carregador de inicialização</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="929"/>
        <source>Select GRUB theme</source>
        <translation>Selecione o tema do GRUB</translation>
    </message>
</context>
</TS>

==> mx-boot-options_21.1.01.tar.xz: mx-boot-options-21.1.01/translations/mx-boot-options_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>CustomDialog</name>
    <message>
        <location filename="../dialog.cpp" line="15"/>
        <source>Live environment detected. Please select the root partition of the
 system you want to modify (only Linux partitions are displayed)</source>
        <translation>Ambiente USB-Executável detectado. Por favor selecione a partição root do
sistema que você quer modificar (apenas partições Linux serão mostradas)</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="22"/>
        <source>OK</source>
        <translation>Aceitar</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="23"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="32"/>
        <source>Options</source>
        <translation>Opções</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="38"/>
        <source>Kernel parameters</source>
        <translation>Parâmetros do Núcleo (Kernel)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="58"/>
        <source>Set to &apos;0&apos; to boot immediately without displaying the menu, or to &apos;-1&apos; to wait indefinitely</source>
        <translation>Ajuste para &quot;0&quot; para iniciar imediatamente sem mostrar o menu, ou, para &quot;-1&quot; para aguardar indefinidamente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="61"/>
        <source>Menu timeout</source>
        <translation>Tempo de espera do menu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="74"/>
        <source>Boot to</source>
        <translation>Iniciar para</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="81"/>
        <source>Use simplified menu structure without submenus</source>
        <translation>Usar menu de estrutura simplificada sem submenus</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="84"/>
        <source>Use flat menus (no submenus)</source>
        <translation>Usar menus condensados (sem submenus)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="113"/>
        <source>seconds</source>
        <translation>segundos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="120"/>
        <source>With this option enabled whatever entry you select from the grub boot menu will be saved as the new default for future boots</source>
        <translation>Com essa opção habilitada qualquer entrada que você selecionar do menu de inicialização do grub será o novo padrão para inicializações futuras</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="123"/>
        <source>Enable saving last boot choice</source>
        <translation>Habilita salvamento da última escolha de inicialização</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="136"/>
        <source>Background</source>
        <translation>Tela de fundo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="154"/>
        <source>Image</source>
        <translation>Imagem</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="167"/>
        <location filename="../mainwindow.ui" line="269"/>
        <source>Enable theme</source>
        <translation>Habilitar tema</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="247"/>
        <source>Splash</source>
        <translation>Tela de início</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="282"/>
        <source>Preview</source>
        <translation>Pré-visualização</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="305"/>
        <source>Messages</source>
        <translation>Mensagens</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="311"/>
        <source>Very detailed</source>
        <translation>Bem detalhado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="318"/>
        <source>Detailed (default setting)</source>
        <translation>Detalhado (ajuste padrão)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="328"/>
        <source>Limited</source>
        <translation>Limitado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="344"/>
        <source>Display log</source>
        <translation>Exibir o relatório</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="397"/>
        <source>Display help </source>
        <translation>Exibir a ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="400"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="407"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="439"/>
        <source>About this application</source>
        <translation>Sobre esta aplicação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="442"/>
        <source>About...</source>
        <translation>Sobre...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="449"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="484"/>
        <source>Quit application</source>
        <translation>Sair da aplicação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="487"/>
        <location filename="../mainwindow.cpp" line="692"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="494"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="535"/>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="67"/>
        <source>Still running</source>
        <translation>Ainda rodando</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="67"/>
        <source>Process still running. Are you sure you want to quit?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="168"/>
        <source>Installing bootsplash, please wait</source>
        <translation>Instalando tela de inicialização, favor aguardar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="175"/>
        <source>Updating sources</source>
        <translation>Atualizando fontes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="177"/>
        <source>Installing</source>
        <translation>Instalando</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="181"/>
        <location filename="../mainwindow.cpp" line="327"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="181"/>
        <source>Could not install the bootsplash.</source>
        <translation>Não pôde instalar a tela de inicialização</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="283"/>
        <location filename="../mainwindow.cpp" line="333"/>
        <source>Cannot continue</source>
        <translation>Não pode continuar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="283"/>
        <source>Nothing was selected, cannot change boot options. Exiting...</source>
        <translation>Nada foi selecionado, não pode mudar opções de inicialização. Saindo...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="328"/>
        <source>Could not create a temporary folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="333"/>
        <source>Cannot create chroot environment, cannot change boot options. Exiting...</source>
        <translation>Não pode criar ambiente chroot, não pode mudar opções de inicialização. Saindo...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="582"/>
        <location filename="../mainwindow.cpp" line="896"/>
        <source>Updating configuration, please wait</source>
        <translation>Atualizando configuração, favor aguardar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="633"/>
        <source>Updating initramfs...</source>
        <translation>Atualizando initramfs...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="643"/>
        <location filename="../mainwindow.cpp" line="909"/>
        <source>Updating grub...</source>
        <translation>Atualizando grub...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="647"/>
        <source>Done</source>
        <translation>Feito</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="647"/>
        <source>Changes have been successfully applied.</source>
        <translation>Mudanças têm sido aplicadas com sucesso</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="660"/>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="661"/>
        <source>Version: </source>
        <translation>Versão: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="662"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Programa para selecionar escolhas comuns de inicialização</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="664"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Direitos de Autor (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="665"/>
        <location filename="../mainwindow.cpp" line="675"/>
        <source>License</source>
        <translation>Licença</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="666"/>
        <location filename="../mainwindow.cpp" line="681"/>
        <source>Changelog</source>
        <translation>Relatório de alterações</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="667"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="711"/>
        <source>MX Boot Options</source>
        <translation>MX Opções de Inicialização</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="723"/>
        <source>Running in a Virtual Machine</source>
        <translation>Rodando em uma Máquina Virtual</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="724"/>
        <source>You current system is running in a Virtual Machine,
Plymouth bootsplash will work in a limited way, you also won&apos;t be able to preview the theme</source>
        <translation>Seu sistema atual está rodando numa Máquina Virtual,
a tela do Plymouth irá trabalhar numa maneira limitada, você também não poderá pré-visualizar o tema.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="729"/>
        <source>Plymouth packages not installed</source>
        <translation>Pacotes do Plymouth não instalados</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="729"/>
        <source>Plymouth packages are not currently installed.
OK to go ahead and install them?</source>
        <translation>Pacotes do Plymouth atualmente não instalados.
Quer prosseguir e instalá-los?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="750"/>
        <source>Images (*.png *.jpg *.jpeg *.tga)</source>
        <translation>Imagens (*.png *.jpg *.jpeg *.tga)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="859"/>
        <source>Press any key to close</source>
        <translation>Pressione qualquer tecla para fechar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="861"/>
        <source>Log not found</source>
        <translation>Relatório não encontrado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="861"/>
        <source>Could not find log at </source>
        <translation>Não pude encontrar relatório em</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="875"/>
        <source>Needs reboot</source>
        <translation>Precisa reiniciar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="875"/>
        <source>Plymouth was just installed, you might need to reboot before being able to display previews</source>
        <translation>Plymouth acabou de ser instalado, você deveria reiniciar antes para poder exibir as pré-visualizações </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="931"/>
        <source>Click to select theme</source>
        <translation>Clique para selecionar o tema</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>You must run this program as root.</source>
        <translation type="vanished">Você deve executar este programa como root.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="42"/>
        <source>Program for selecting common start-up choices</source>
        <translation type="unfinished">Programa para selecionar escolhas comuns de inicialização</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../mainwindow.cpp" line="749"/>
        <source>Select image to display in bootloader</source>
        <translation>Selecione imagem para exibir no carregador de inicialização</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="941"/>
        <source>Select GRUB theme</source>
        <translation>Selecione o tema do GRUB</translation>
    </message>
</context>
</TS>
